import re

class ExosParse:
    def __init__(self, raw):
        self.raw=raw
        self.result=dict()

    def getip(self):
        ip=list()
        p=re.compile('^ipaddr')
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                ip=i.split(':')
        if ip:
            self.result['ip']=ip[1].strip()
        else:
            self.result['ip']='unknown'
        return self.result

    def getmodel(self):
        model=list()
        p=re.compile('^System Type')
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                model=i.split(':')
        if model:
            self.result['model']=model[1].strip()
        else:
            self.result['model']='unknown'
        return self.result

    def gethostname(self):
        hosts=list()
        p=re.compile('SysName')
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                hosts=i.split(':')
        if hosts:
            self.result['hostname']=hosts[1].strip()
        else:
            self.result['hostname']='unknown'
        return self.result

    def getcpu(self):
        cpu=list()
        p=re.compile('^System\s+([0-9]+[.][0-9]+\s)+')
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                cpu=i.split(' ')
        if cpu:
            self.result['cpu util']=cpu[7]+'%'
        else:
            self.result['cpu util']='unknown'
        return self.result

    def getmem(self):
        tot=list()
        free=list()
        p1=re.compile('Total\s+DRAM')
        p2=re.compile('Free\s+[(]KB[)]')
        for i in self.raw:
            m=p1.search(i)
            if m:
                i=' '.join(i.split())
                tot=i.split(' ')
        for i in self.raw:
            m=p2.search(i)
            if m:
                i=' '.join(i.split())
                free=i.split(' ')
        if tot and free:
            usage=(int(tot[-1].strip())-int(free[-1].strip()))*100/int(tot[-1].strip())
            self.result['mem util']=str(int(usage))+'%'
        else:
            self.result['mem util']='unknown'
        return self.result

    def gettemp(self):
        tempr=list()
        p=re.compile('^Switch\s+[:]')
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                tempr=i.split(' ')
        if tempr:
            self.result['temperature']='%s℃ %s' %(tempr[3].strip(), tempr[4].strip())
        else:
            self.result['temperature']='unknown'
        return self.result

    def getfan(self):
        fan=list()
        p=re.compile('Fan-[0-9]+')
        flag=1 # 1 is normal, 0 has some problems.
        for i in self.raw:
            m=p.search(i)
            if m:
                i=' '.join(i.split())
                fan=i.split(' ')
                if fan[1].strip()=='Failed':
                    flag=0
        if fan and flag==1:
            self.result['fan']='operational'
        elif fan and flag==0:
            self.result['fan']='Failed'
        else:
            self.result['fan']='unknown'
        return self.result

    def getpower(self):
        ps=list()
        p=re.compile('^PowerSupply')
        i=0
        stat=str()
        flag=1 # 1 is normal, 0 has some problems..
        for i in range(0, len(self.raw)):
            m=p.search(self.raw[i])
            if m:
                tmp=' '.join(self.raw[i+1].split())
                ps=tmp.split(':')
                print(ps)
                if ps[1].strip()!='Powered On':
                    if ps[1].strip()!='Empty':
                        flag=0
                        stat=ps[1].strip()
        if ps and flag==1:
            self.result['power']='On'
        elif ps and flag==0:
            self.result['power']=stat
        else:
            self.result['power']='unknown'
        return self.result

    def saveresult(self):
        self.getip()
        self.getmodel()
        self.gethostname()
        self.getcpu()
        self.getmem()
        self.gettemp()
        self.getfan()
        self.getpower()
        return self.result

if __name__=='__main__':
    f=open('raw.txt')
    s=f.read()
    f.close()
    raw=s.split('\n')
    switch=ExosParse(raw)
    result=switch.saveresult()
    print(result)
